paidiverpy.models.sampling_params
=================================

.. py:module:: paidiverpy.models.sampling_params

.. autoapi-nested-parse::

   Sampling parameters dataclasses.

   This module contains the dataclasses for the parameters of the convert layer
   functions.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.models.sampling_params.SamplingDatetimeParams
   paidiverpy.models.sampling_params.SamplingDepthParams
   paidiverpy.models.sampling_params.SamplingAltitudeParams
   paidiverpy.models.sampling_params.SamplingPitchRollParams
   paidiverpy.models.sampling_params.SamplingOverlappingParams
   paidiverpy.models.sampling_params.SamplingFixedParams
   paidiverpy.models.sampling_params.SamplingPercentParams
   paidiverpy.models.sampling_params.SamplingRegionParams
   paidiverpy.models.sampling_params.SamplingObscureParams


Module Contents
---------------

.. py:class:: SamplingDatetimeParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for datetime resampling.
















   ..
       !! processed by numpydoc !!

.. py:class:: SamplingDepthParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for depth resampling.
















   ..
       !! processed by numpydoc !!

.. py:class:: SamplingAltitudeParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for altitude resampling.
















   ..
       !! processed by numpydoc !!

.. py:class:: SamplingPitchRollParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for pitch and roll resampling.
















   ..
       !! processed by numpydoc !!

.. py:class:: SamplingOverlappingParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for overlapping resampling.
















   ..
       !! processed by numpydoc !!

.. py:class:: SamplingFixedParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for fixed interval resampling.
















   ..
       !! processed by numpydoc !!

.. py:class:: SamplingPercentParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for percent-based resampling.
















   ..
       !! processed by numpydoc !!

.. py:class:: SamplingRegionParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for region-based resampling.
















   ..
       !! processed by numpydoc !!

.. py:class:: SamplingObscureParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for obscure-based resampling.
















   ..
       !! processed by numpydoc !!

